@@ -120,6 +120,7 @@ insert_image_cb (BonoboUIComponent *uic, GtkHTMLControlData *cd, const char *cna
 			filename = gtk_file_selection_get_filename (GTK_FILE_SELECTION (filesel));
 #endif
 			url = gtk_html_filename_to_uri (filename);
+			g_free(filename);
 			img = html_image_new (html_engine_get_image_factory (cd->html->engine), url,
 					      NULL, NULL, 0, 0, 0, 0, 0, NULL, HTML_VALIGN_NONE, FALSE);
 			html_engine_paste_object (cd->html->engine, img, 1);
@@ -329,7 +330,7 @@ insert_file_dialog (GtkHTMLControlData *cd, gboolean html)
 	}
 
 #ifdef USE_GTKFILECHOOSER
-	cd->file_dialog = gtk_file_chooser_dialog_new (html ? _("Insert: HTML File") : _("Insert: Text File"),
+	cd->file_dialog = gtk_file_chooser_dialog_new (html ? _("Insert HTML File") : _("Insert Text File"),
 						       NULL,
 						       GTK_FILE_CHOOSER_ACTION_OPEN,
 						       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -338,7 +339,7 @@ insert_file_dialog (GtkHTMLControlData *cd, gboolean html)
 	gtk_dialog_set_default_response (GTK_DIALOG (cd->file_dialog), GTK_RESPONSE_OK);
 	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (cd->file_dialog), g_get_home_dir ());
 #else
-	cd->file_dialog = gtk_file_selection_new (html ? _("Insert: HTML File") : _("Insert: Text File"));
+	cd->file_dialog = gtk_file_selection_new (html ? _("Insert HTML File") : _("Insert Text File"));
 	gtk_file_selection_set_filename (GTK_FILE_SELECTION (cd->file_dialog), "~/");
 #endif
 
@@ -372,11 +373,15 @@ spell_check_cb (BonoboUIComponent *uic, GtkHTMLControlData *cd, const char *cnam
 static void
 format_page_cb (BonoboUIComponent *uic, GtkHTMLControlData *cd, const char *cname)
 {
+	char *filename;
+
 	if (cd->properties_dialog)
 		gtk_html_edit_properties_dialog_close (cd->properties_dialog);
 
+	filename = gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_properties", 16, NULL, NULL);
 	cd->properties_dialog = gtk_html_edit_properties_dialog_new (cd, _("Format"),
-								     gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_properties", 16, NULL, NULL));
+								     filename);
+	g_free(filename);
 
 	gtk_html_edit_properties_dialog_add_entry (cd->properties_dialog,
 						   GTK_HTML_EDIT_PROPERTY_BODY, _("Page"),
@@ -390,11 +395,15 @@ format_page_cb (BonoboUIComponent *uic, GtkHTMLControlData *cd, const char *cnam
 static void
 format_text_cb (BonoboUIComponent *uic, GtkHTMLControlData *cd, const char *cname)
 {
+	char *filename;
+
 	if (cd->properties_dialog)
 		gtk_html_edit_properties_dialog_close (cd->properties_dialog);
 
+	filename = gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_properties", 16, NULL, NULL);
 	cd->properties_dialog = gtk_html_edit_properties_dialog_new (cd, _("Format"),
-								     gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_properties", 16, NULL, NULL));
+								     filename);
+	g_free(filename);
 
 	gtk_html_edit_properties_dialog_add_entry (cd->properties_dialog,
 						   GTK_HTML_EDIT_PROPERTY_BODY, _("Text"),
@@ -408,11 +417,15 @@ format_text_cb (BonoboUIComponent *uic, GtkHTMLControlData *cd, const char *cnam
 static void
 format_paragraph_cb (BonoboUIComponent *uic, GtkHTMLControlData *cd, const char *cname)
 {
+	char *filename;
+
 	if (cd->properties_dialog)
 		gtk_html_edit_properties_dialog_close (cd->properties_dialog);
 
+	filename = gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_properties", 16, NULL, NULL);
 	cd->properties_dialog = gtk_html_edit_properties_dialog_new (cd, _("Format"),
-								     gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_properties", 16, NULL, NULL));
+								     filename);
+	g_free(filename);
 
 	gtk_html_edit_properties_dialog_add_entry (cd->properties_dialog,
 						   GTK_HTML_EDIT_PROPERTY_BODY, _("Paragraph"),
@@ -627,28 +640,6 @@ menubar_update_format (GtkHTMLControlData *cd)
 					      "sensitive", sensitive, &ev);
 		bonobo_ui_component_set_prop (uic, "/commands/InsertTemplate",
 					      "sensitive", sensitive, &ev);
-		bonobo_ui_component_set_prop (uic, "/commands/InsertSmiley1",
-					      "sensitive", sensitive, &ev);
-		bonobo_ui_component_set_prop (uic, "/commands/InsertSmiley2",
-					      "sensitive", sensitive, &ev);
-		bonobo_ui_component_set_prop (uic, "/commands/InsertSmiley3",
-					      "sensitive", sensitive, &ev);
-		bonobo_ui_component_set_prop (uic, "/commands/InsertSmiley4",
-					      "sensitive", sensitive, &ev);
-		bonobo_ui_component_set_prop (uic, "/commands/InsertSmiley5",
-					      "sensitive", sensitive, &ev);
-		bonobo_ui_component_set_prop (uic, "/commands/InsertSmiley6",
-					      "sensitive", sensitive, &ev);
-		bonobo_ui_component_set_prop (uic, "/commands/InsertSmiley8",
-					      "sensitive", sensitive, &ev);
-		bonobo_ui_component_set_prop (uic, "/commands/InsertSmiley9",
-					      "sensitive", sensitive, &ev);
-		bonobo_ui_component_set_prop (uic, "/commands/InsertSmiley10",
-					      "sensitive", sensitive, &ev);
-		bonobo_ui_component_set_prop (uic, "/commands/InsertSmiley11",
-					      "sensitive", sensitive, &ev);
-		bonobo_ui_component_set_prop (uic, "/commands/InsertSmiley12",
-					      "sensitive", sensitive, &ev);
 
 		bonobo_ui_component_set_prop (uic, "/commands/FormatBold",
 					      "sensitive", sensitive, &ev);
@@ -688,17 +679,26 @@ menubar_set_languages (GtkHTMLControlData *cd)
 	GString *str;
 	gboolean enabled;
 	gint i;
+	gint no_of_lang=0;
 
-	if (!cd->languages)
+	if (!cd->languages) {
+		bonobo_ui_component_set_prop (cd->uic, "/commands/EditSpellCheck", "sensitive", "0", NULL);
 		return;
+	}
 
 	str = g_string_new (NULL);
 	cd->block_language_changes = TRUE;
 	for (i = 0; i < cd->languages->_length; i ++) {
 		enabled = cd->language && strstr (cd->language, cd->languages->_buffer [i].abbreviation) != NULL;
+		if (enabled)
+			no_of_lang++;
 		g_string_printf (str, "/commands/SpellLanguage%d", i + 1);
 		bonobo_ui_component_set_prop (cd->uic, str->str, "state", enabled ? "1" : "0", NULL);
 	}
+	if (no_of_lang > 0)
+		bonobo_ui_component_set_prop (cd->uic, "/commands/EditSpellCheck", "sensitive", "1", NULL);
+	else
+		bonobo_ui_component_set_prop (cd->uic, "/commands/EditSpellCheck", "sensitive", "0", NULL);
 	g_string_free (str, TRUE);
 	cd->block_language_changes = FALSE;
 }
